# -*- encoding: utf-8 -*-
# Copyright (c) 2015 b<>com
#
# Authors: Jean-Emile DARTOIS <jean-emile.dartois@b-com.com>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
# implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
import six


@six.add_metaclass(abc.ABCMeta)
class BaseStrategyContext(object):

    @abc.abstractmethod
    def execute_strategy(self, audit, request_context):
        """Execute the strategy for the given an audit

        :param audit: Audit object
        :type audit: :py:class:`~.objects.audit.Audit` instance
        :param request_context: Current request context
        :type request_context: :py:class:`~.RequestContext` instance
        :returns: The computed solution
        :rtype: :py:class:`~.BaseSolution` instance
        """
        raise NotImplementedError()
